@@ -100,6 +100,10 @@ define(/libname/, dnl
 patsubst(patsubst($1, /lib\([^\.]*\)\.a/, /\1/), /-l/, //))dnl
 changequote([,])dnl
 @@@libs="$libs libname"@@@
+# If it was found, we do:
+$2
+# If it was not found, we do:
+$3
 ])dnl
 '
 
@@ -109,16 +113,25 @@ funcs=
 headers=
 libs=
 
-# We extract assignments of SYMS, FUNCS, HEADERS, and LIBS from the modified
-# autoconf processing of the input file.
+# We extract assignments of SYMS, FUNCS, HEADERS, and LIBS from the
+# modified autoconf processing of the input file.  The sed hair is
+# necessary to win for multi-line macro invocations.
 eval "`echo \"$frob\" \
        | $M4 $MACROFILES - $infile \
-       | sed -n -e 's/^@@@\(.*\)@@@$/\1/p'`"
+       | sed -n -e '
+		: again
+		/^@@@.*@@@$/s/^@@@\(.*\)@@@$/\1/p
+		/^@@@/{
+			s/^@@@//p
+			n
+			s/^/@@@/
+			b again
+		}'`"
 
 test -n "$print_version" && exit 0
 
-# Make SYMS newline-separated rather than blank-separated.
-syms="`for sym in $syms; do echo $sym; done`"
+# Make SYMS newline-separated rather than blank-separated, and remove dups.
+syms="`for sym in $syms; do echo $sym; done | sort | uniq`"
 
 if test $# -eq 0; then
   tmpout=autoh$$
@@ -153,25 +166,25 @@ if test -n "$syms"; then
    tr @ \\012
 fi
 
-for func in $funcs; do
+for func in `for x in $funcs; do echo $x; done | sort | uniq`; do
   sym="`echo ${func} | sed 's/[^a-zA-Z0-9_]/_/g' | tr '[a-z]' '[A-Z]'`"
   echo "
 /* Define if you have ${func}.  */
 #undef HAVE_${sym}"
 done
 
-for header in $headers; do
+for header in `for x in $headers; do echo $x; done | sort | uniq`; do
   sym="`echo ${header} | sed 's/[^a-zA-Z0-9_]/_/g' | tr '[a-z]' '[A-Z]'`"
   echo "
 /* Define if you have the <${header}> header file.  */
 #undef HAVE_${sym}"
 done
 
-for lib in $libs; do
+for lib in `for x in $libs; do echo $x; done | sort | uniq`; do
   sym="`echo ${lib} | sed 's/[^a-zA-Z0-9_]/_/g' | tr '[a-z]' '[A-Z]'`"
   echo "
 /* Define if you have the ${lib} library (-l${lib}).  */
-#undef HAVE_${sym}"
+#undef HAVE_LIB${sym}"
 done
 
 status=0
@@ -187,7 +200,11 @@ done
 
 if test $# -eq 0; then
   if test $status -eq 0; then
-    mv -f $tmpout ${config_h}.in
+    if cmp -s $tmpout ${config_h}.in; then
+      rm -f $tmpout
+    else
+      mv -f $tmpout ${config_h}.in
+    fi
   else
     rm -f $tmpout
   fi
